/*
 * Copyright (c) 2023 Nordic Semiconductor ASA
 *
 * SPDX-License-Identifier: BSD-3-Clause
 */

/*
 * @file	generic/atomic.h
 * @brief	Generic environment atomic primitives for libmetal.
 */

#ifndef __METAL_GENERIC_ATOMIC__H__
#define __METAL_GENERIC_ATOMIC__H__

#endif /* __METAL_GENERIC_ATOMIC__H__ */
